function mfit = ga_obj_fun(mod,dat,par,cfg,ns)

%-----------------------------------
% Misfit function computation
mfit = 0;

%-----------------------------------
% Generate model profile
[out.hl out.vp out.vs out.dn] = ga_gen_profile(mod,cfg,par,ns);

%-----------------------------------
% Fitting Rayleigh wave ellipticity
if (cfg.elck > 0)
  % Forward model
  out.ellc = ellipticity_curve_rayleigh...
             (out.hl,out.vp,out.vs,out.dn,dat.file(ns).fr,1);

  % Misfit calculation
  ind = find(out.ellc ~= -1 & dat.file(ns).hv ~= -1);
  fval0 = log10(out.ellc(ind));
  fval1 = log10(dat.file(ns).hv(ind));
  mfit = mfit + cfg.elwg*sum((fval1-fval0).^2)/numel(ind);
end

%-----------------------------------
% Fitting Rayleigh wave f0
if (cfg.f0ck > 0)
  % Forward model
  out.ell0 = ellipticity_curve_rayleigh...
             (out.hl,out.vp,out.vs,out.dn,dat.freq,1);

  % Extract f0 frequency
  out.elf0 = NaN;
  mi = local_max(out.ell0);
  if (numel(mi) ~= 0)
    out.elf0 = dat.freq(mi(1));
  end

  % Misfit calculation
  fval0 = log10(out.elf0);
  fval1 = log10(dat.f0(ns));
  mfit = mfit + cfg.f0wg*(fval1-fval0).^2;
end

%-----------------------------------
% Plot
if (cfg.plot)
  ga_fit_plot(cfg,dat,out,ns);
end

return;

