function hv_glob_opt (varargin)

%-----------------------------------
% Initialization
close all; clear mex;
dispersion_curve_init;

%-----------------------------------
% Check for input file
if (nargin ~= 1)
  disp('Error: configuration file not specified.');
  disp('Exit program...');
  return;
end

%-----------------------------------
% Import configration
f01 = fopen(varargin{1});
if (f01 ~= -1)
  cfg = ga_read_cfg(f01);
else
  disp('Error: cannot open configuration file.');
  disp('Exit program...');
  return;
end
fclose(f01);

%-----------------------------------
% Import HV data files
dat = ga_read_data(cfg);

%-----------------------------------
% Set local variables
dat = ga_loc_var(dat);

%-----------------------------------
% Generate parametrization
par = ga_gen_par(dat,cfg);

%-----------------------------------
% GA inversion core
options = gaoptimset('StallTimeLimit',Inf, ...
                     'StallGenLimit',Inf, ...
                     'Generations',Inf, ...
                     'TimeLimit',cfg.tlim, ...
                     'UseParallel','Always', ...
                     'PopulationSize',100,...
                     'EliteCount',1,...
                     'TolFun',0, ...
                     'TolCon',0);

%-----------------------------------
% Loop over stations
for ns = 1:dat.sn

  % Optimization
  [mod mfit] = ga(@(mod)ga_obj_fun(mod,dat,par,cfg,ns), ...
               par.nvar,[],[],[],[],par.lb,par.ub,[],options);

  % Save Output
  ga_save_out(ns,cfg,dat,mod);

end

return;

